import { API as ParentAPI } from '../../../bridge';
import type { WaitForOptions, Zone } from '../../../bridge';
import type { CreateSnapshotRequest, CreateVolumeRequest, DeleteSnapshotRequest, DeleteVolumeRequest, GetSnapshotRequest, GetVolumeRequest, ImportSnapshotFromS3Request, ListSnapshotsRequest, ListSnapshotsResponse, ListVolumeTypesRequest, ListVolumeTypesResponse, ListVolumesRequest, ListVolumesResponse, Snapshot, UpdateSnapshotRequest, UpdateVolumeRequest, Volume } from './types.gen';
/**
 * Scaleway Block Storage API.
 *
 * This API allows you to manage your Block Storage volumes.
 */
export declare class API extends ParentAPI {
    /** Lists the available zones of the API. */
    static readonly LOCALITIES: Zone[];
    protected pageOfListVolumeTypes: (request?: Readonly<ListVolumeTypesRequest>) => Promise<ListVolumeTypesResponse>;
    /**
     * List volume types. List all available volume types in a specified zone. The
     * volume types listed are ordered by name in ascending order.
     *
     * @param request - The request {@link ListVolumeTypesRequest}
     * @returns A Promise of ListVolumeTypesResponse
     */
    listVolumeTypes: (request?: Readonly<ListVolumeTypesRequest>) => Promise<ListVolumeTypesResponse> & {
        all: () => Promise<import("./types.gen").VolumeType[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").VolumeType[], void, void>;
    };
    protected pageOfListVolumes: (request?: Readonly<ListVolumesRequest>) => Promise<ListVolumesResponse>;
    /**
     * List volumes. List all existing volumes in a specified zone. By default,
     * the volumes listed are ordered by creation date in ascending order. This
     * can be modified via the `order_by` field.
     *
     * @param request - The request {@link ListVolumesRequest}
     * @returns A Promise of ListVolumesResponse
     */
    listVolumes: (request?: Readonly<ListVolumesRequest>) => Promise<ListVolumesResponse> & {
        all: () => Promise<Volume[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Volume[], void, void>;
    };
    /**
     * Create a volume. To create a new volume from scratch, you must specify
     * `from_empty` and the `size`. To create a volume from an existing snapshot,
     * specify `from_snapshot` and the `snapshot_id` in the request payload
     * instead, size is optional and can be specified if you need to extend the
     * original size. The volume will take on the same volume class and underlying
     * IOPS limitations as the original snapshot.
     *
     * @param request - The request {@link CreateVolumeRequest}
     * @returns A Promise of Volume
     */
    createVolume: (request: Readonly<CreateVolumeRequest>) => Promise<Volume>;
    /**
     * Get a volume. Retrieve technical information about a specific volume.
     * Details such as size, type, and status are returned in the response.
     *
     * @param request - The request {@link GetVolumeRequest}
     * @returns A Promise of Volume
     */
    getVolume: (request: Readonly<GetVolumeRequest>) => Promise<Volume>;
    /**
     * Waits for {@link Volume} to be in a final state.
     *
     * @param request - The request {@link GetVolumeRequest}
     * @param options - The waiting options
     * @returns A Promise of Volume
     */
    waitForVolume: (request: Readonly<GetVolumeRequest>, options?: Readonly<WaitForOptions<Volume>>) => Promise<Volume>;
    /**
     * Delete a detached volume. You must specify the `volume_id` of the volume
     * you want to delete. The volume must not be in the `in_use` status.
     *
     * @param request - The request {@link DeleteVolumeRequest}
     */
    deleteVolume: (request: Readonly<DeleteVolumeRequest>) => Promise<void>;
    /**
     * Update a volume. Update the technical details of a volume, such as its
     * name, tags, or its new size and `volume_type` (within the same Block
     * Storage class). You can only resize a volume to a larger size. It is
     * currently not possible to change your Block Storage Class.
     *
     * @param request - The request {@link UpdateVolumeRequest}
     * @returns A Promise of Volume
     */
    updateVolume: (request: Readonly<UpdateVolumeRequest>) => Promise<Volume>;
    protected pageOfListSnapshots: (request?: Readonly<ListSnapshotsRequest>) => Promise<ListSnapshotsResponse>;
    /**
     * List all snapshots. List all available snapshots in a specified zone. By
     * default, the snapshots listed are ordered by creation date in ascending
     * order. This can be modified via the `order_by` field.
     *
     * @param request - The request {@link ListSnapshotsRequest}
     * @returns A Promise of ListSnapshotsResponse
     */
    listSnapshots: (request?: Readonly<ListSnapshotsRequest>) => Promise<ListSnapshotsResponse> & {
        all: () => Promise<Snapshot[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Snapshot[], void, void>;
    };
    /**
     * Get a snapshot. Retrieve technical information about a specific snapshot.
     * Details such as size, volume type, and status are returned in the
     * response.
     *
     * @param request - The request {@link GetSnapshotRequest}
     * @returns A Promise of Snapshot
     */
    getSnapshot: (request: Readonly<GetSnapshotRequest>) => Promise<Snapshot>;
    /**
     * Waits for {@link Snapshot} to be in a final state.
     *
     * @param request - The request {@link GetSnapshotRequest}
     * @param options - The waiting options
     * @returns A Promise of Snapshot
     */
    waitForSnapshot: (request: Readonly<GetSnapshotRequest>, options?: Readonly<WaitForOptions<Snapshot>>) => Promise<Snapshot>;
    /**
     * Create a snapshot of a volume. To create a snapshot, the volume must be in
     * the `in_use` or the `available` status. If your volume is in a transient
     * state, you need to wait until the end of the current operation.
     *
     * @param request - The request {@link CreateSnapshotRequest}
     * @returns A Promise of Snapshot
     */
    createSnapshot: (request: Readonly<CreateSnapshotRequest>) => Promise<Snapshot>;
    /**
     * Import a snapshot from a Scaleway Object Storage bucket. The bucket must
     * contain a QCOW2 image. The bucket can be imported into any Availability
     * Zone as long as it is in the same region as the bucket.
     *
     * @param request - The request {@link ImportSnapshotFromS3Request}
     * @returns A Promise of Snapshot
     */
    importSnapshotFromS3: (request: Readonly<ImportSnapshotFromS3Request>) => Promise<Snapshot>;
    /**
     * Delete a snapshot. You must specify the `snapshot_id` of the snapshot you
     * want to delete. The snapshot must not be in use.
     *
     * @param request - The request {@link DeleteSnapshotRequest}
     */
    deleteSnapshot: (request: Readonly<DeleteSnapshotRequest>) => Promise<void>;
    /**
     * Update a snapshot. Update the name or tags of the snapshot.
     *
     * @param request - The request {@link UpdateSnapshotRequest}
     * @returns A Promise of Snapshot
     */
    updateSnapshot: (request: Readonly<UpdateSnapshotRequest>) => Promise<Snapshot>;
}
